=====================
 zope.securitypolicy
=====================

.. image:: https://img.shields.io/pypi/v/zope.securitypolicy.svg
   :target: https://pypi.org/project/zope.securitypolicy/
   :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/zope.securitypolicy.svg
   :target: https://pypi.org/project/zope.securitypolicy/
   :alt: Supported Python versions

.. image:: https://github.com/zopefoundation/zope.securitypolicy/actions/workflows/tests.yml/badge.svg
   :target: https://github.com/zopefoundation/zope.securitypolicy/actions/workflows/tests.yml

.. image:: https://coveralls.io/repos/github/zopefoundation/zope.securitypolicy/badge.svg?branch=master
   :target: https://coveralls.io/github/zopefoundation/zope.securitypolicy?branch=master



This package provides an useful security policy for Zope3. It's the
default security policy used in "zope3 the application" and many other
zope-based projects.
